pub struct Message {
pub role: Role,
pub parts: Vec<Part>,
pub message_id: Option<String>,
pub task_id: Option<String>,
pub context_id: Option<String>,
pub metadata: Option<Value>,
}Fields
role: Roleparts: Vec<Part>message_id: Option<String>task_id: Option<String>context_id: Option<String>metadata: Option<Value>Implementations
Sourceimpl Message
impl Message
pub fn user_text(s: impl Into<String>) -> Self
pub fn text_content(&self) -> Option<&str>
Sourcepub fn all_text_content(&self) -> String
pub fn all_text_content(&self) -> String
Collect and concatenate all Part::Text entries in order.
Unlike [text_content] which returns only the first text part, this method
preserves the full message when an agent sends multiple text parts.
Returns an empty string if the message contains no text parts.